@@ -7,6 +7,8 @@ from weaverbird.backends.pypika_translator.translators.base import SQLTranslator
 class AthenaTranslator(SQLTranslator):
     DIALECT = SQLDialect.ATHENA
     QUERY_CLS = Query
+    SUPPORT_ROW_NUMBER = True
+    SUPPORT_SPLIT_PART = True
 
 
 SQLTranslator.register(AthenaTranslator)
