@@ -30,6 +30,7 @@ if TYPE_CHECKING:
     from weaverbird.pipeline import PipelineStep
     from weaverbird.pipeline.conditions import Condition, SimpleCondition
     from weaverbird.pipeline.steps import (
+        AbsoluteValueStep,
         AggregateStep,
         ArgmaxStep,
         ArgminStep,
@@ -78,6 +79,11 @@ class DataTypeMapping:
     text: str
 
 
+class CustomQuery(AliasedQuery):  # type: ignore[misc]
+    def get_sql(self, **kwargs: Any) -> str:
+        return cast(str, self.query)
+
+
 class SQLTranslator(ABC):
     DIALECT: SQLDialect
     QUERY_CLS: Query
@@ -145,6 +151,14 @@ class SQLTranslator(ABC):
         self: Self, agg_function: "AggregateFn"
     ) -> functions.AggregateFunction:
         match agg_function:
+            # Commenting this since postgres and redshift
+            # doesn't support it
+            # case "first":
+            #     return functions.First
+            # case "last":
+            #     return functions.Last
+            # case "abs":
+            #     return functions.Abs
             case "avg":
                 return functions.Avg
             case "count":
@@ -162,6 +176,16 @@ class SQLTranslator(ABC):
                     f"[{self.DIALECT}] Aggregation for {agg_function!r} is not yet implemented"
                 )
 
+    def absolutevalue(
+        self: Self, *, step: "AbsoluteValueStep", table: StepTable
+    ) -> tuple["QueryBuilder", StepTable]:
+        col_field: Field = Table(table.name)[step.column]
+        query: "QueryBuilder" = self.QUERY_CLS.from_(table.name).select(
+            *table.columns,
+            functions.Abs(col_field).as_(step.new_column),
+        )
+        return query, StepTable(columns=[*table.columns, step.new_column])
+
     def aggregate(
         self: Self, *, step: "AggregateStep", table: StepTable
     ) -> tuple["QueryBuilder", StepTable]:
@@ -278,10 +302,6 @@ class SQLTranslator(ABC):
     ) -> tuple["QueryBuilder", StepTable]:
         """create a custom sql step based on the current table named ##PREVIOUS_STEP## in the query"""
 
-        class CustomQuery(AliasedQuery):  # type: ignore[misc]
-            def get_sql(self, **kwargs: Any) -> str:
-                return cast(str, self.query)
-
         if table.name is None:
             raise MissingTableNameError()
 
@@ -455,6 +475,7 @@ class SQLTranslator(ABC):
         #   [my age] + 1 / 2
         # into
         #   CAST("my age" AS float) + 1 / 2
+
         query = query.select(LiteralValue(step.formula).as_(step.new_column))
         return query, StepTable(columns=[*table.columns, step.new_column])
 
@@ -614,7 +635,7 @@ class SQLTranslator(ABC):
         self: Self, *, step: "SubstringStep", table: StepTable
     ) -> tuple["QueryBuilder", StepTable]:
         step.new_column_name = (
-            f"{step.column}_SUBSTR" if step.new_column_name is None else step.new_column_name
+            f"{step.column}_substr" if step.new_column_name is None else step.new_column_name
         )
         col_field: Field = Table(table.name)[step.column]
         query: "QueryBuilder" = self.QUERY_CLS.from_(table.name).select(
@@ -670,11 +691,15 @@ class SQLTranslator(ABC):
                     RowNumber()
                     .over(*groups_fields)
                     .orderby(rank_on_field, order=Order.desc if step.sort == "desc" else Order.asc)
+                    .as_("row_number")
                 )
                 query: "QueryBuilder" = (
                     self.QUERY_CLS.from_(sub_query)
                     .select(*table.columns)
-                    .where(Field("row_number") == step.limit)
+                    .where(Field("row_number") <= step.limit)
+                    # The order of returned results is not necessarily consistent. This ensures we
+                    # always get the results in the same order
+                    .orderby(*(Field(f) for f in step.groups + ["row_number"]), order=Order.asc)
                 )
                 return query, StepTable(columns=table.columns)
 
