@@ -1,5 +1,6 @@
-from typing import Any, Callable, List, Optional, Protocol, Tuple
+from typing import Any, Callable, List, Literal, Optional, Protocol, Tuple
 
+from pandas import DataFrame
 from pydantic import BaseModel
 
 from weaverbird.backends.sql_translator.metadata import SqlQueryMetadataManager
@@ -27,12 +28,13 @@ class SQLQuery(BaseModel):
 
 SQLQueryRetriever = Callable[[str], str]
 SQLQueryDescriber = Callable
-SQLQueryExecutor = Callable[[str, str], str]
+SQLQueryExecutor = Callable[[str, str], DataFrame]
 
 SQLPipelineTranslator = Callable[
     [Pipeline, SQLQueryRetriever, SQLQueryDescriber, SQLQueryExecutor],
     Tuple[str, SQLPipelineTranslationReport],
 ]
+SQLDialect = Literal['snowflake', 'postgres']
 
 
 class SQLStepTranslator(Protocol):
@@ -46,5 +48,6 @@ class SQLStepTranslator(Protocol):
         sql_query_executor: Optional[SQLQueryExecutor],
         sql_translate_pipeline: Optional[SQLPipelineTranslator],
         subcall_from_other_pipeline_count: Optional[int],
+        sql_dialect: Optional[SQLDialect],
     ):
         ...
