@@ -1,6 +1,4 @@
-from typing import List, Union
-
-from pydantic import Field
+from typing import List, Literal, Union
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMixin
@@ -8,7 +6,7 @@ from weaverbird.pipeline.types import ColumnName, TemplatedVariable
 
 
 class UnpivotStep(BaseStep):
-    name = Field('unpivot', const=True)
+    name: Literal['unpivot'] = 'unpivot'
     keep: List[ColumnName]
     unpivot: List[ColumnName]
     unpivot_column_name: ColumnName
